# ecoe Package

### This package is in the process of being developed, and is NOT intended for use at this time.

This package provides a number of functions for common 
analysis tasks in Ecological Engineering
